<?php

namespace SM\Factory;

use Doctrine\ORM\EntityManager;
use SM\Traits\TQuery;

class Sm00057002ConfiguracaoRegionalMoedaFactory
{

    use TQuery;

    protected $connection;

    protected $entityManager;

    public function __construct(EntityManager $entityManager)
    {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }

    public function getConfiguracaoRegionalMoeda()
    {
        $sql = "SELECT NRMOEDA,              
                       NMMOEDA,        
                       SIMBOLOMOEDA,               
                       CDISOMOEDA,                 
                       IDATIVO,           
                       NRORG,               
                       DTINCLUSAO,             
                       NRORGINCLUSAO,       
                       CDOPERINCLUSAO, 
                       DTULTATU,                       
                       NRORGULTATU,                    
                       CDOPERULTATU,
                       IDPADRAO
                  FROM FCT_MOEDA";
        
        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function validaConfiguracaoRegionalMoeda($parametros)
    {

        $sql = "SELECT COUNT(*) AS VALIDAMOEDA
                  FROM FCT_MOEDA
                 WHERE NMMOEDA = :NMMOEDA
                   AND NRMOEDA <> NVL(:NRMOEDA ,-1)";
        $std = $this->connection->prepare($sql);
        $std->execute($parametros);
        return $std->fetchAll(); 
    }

    public function inserirConfiguracaoRegionalMoeda($parametros)
    {
        $sql = "INSERT INTO  FCT_MOEDA (
                NRMOEDA, NMMOEDA,SIMBOLOMOEDA,CDISOMOEDA,IDATIVO, NRORG, DTINCLUSAO,
                NRORGINCLUSAO,CDOPERINCLUSAO,
                IDPADRAO)
                VALUES (
                 :NRMOEDA, :NMMOEDA,:SIMBOLOMOEDA,:CDISOMOEDA,:IDATIVO, :NRORG, SYSDATE,    
                 :NRORGINCLUSAO,:CDOPERINCLUSAO,
                 :IDPADRAO
                )";
            $this->connection->executeStatement($sql, $parametros);
    }

    public function atualizarConfiguracaoRegionalMoeda($parametros)
    {
        $sql = "UPDATE FCT_MOEDA
                   SET NMMOEDA = :NMMOEDA,
                       SIMBOLOMOEDA = :SIMBOLOMOEDA,
                       CDISOMOEDA = :CDISOMOEDA,
                       IDATIVO = :IDATIVO,
                       NRORG = :NRORG,
                       DTULTATU = SYSDATE,
                       NRORGULTATU = :NRORGULTATU,
                       CDOPERULTATU = :CDOPERULTATU,
                       IDPADRAO = :IDPADRAO
                 WHERE NRMOEDA  = :NRMOEDA";

        $this->connection->executeStatement($sql, $parametros);
    }

    public function atualizarConfiguracaoRegionalIdPadraoMoeda($parametros)
    {

        $sql = "UPDATE FCT_MOEDA
               SET 
                    IDPADRAO = :IDPADRAO
                WHERE NRMOEDA  <> :NRMOEDA";
            $this->connection->executeStatement($sql, $parametros);
    }

    public function deletarConfiguracaoRegionalMoeda($parametros)
    {
        $sql = "DELETE FROM FCT_MOEDA WHERE NRMOEDA  = :NRMOEDA  ";
        $this->connection->executeStatement($sql, $parametros);
    }
}
