<?php

namespace SM\Service;

use SM\Factory\Sm00034001DescontoPeriodoCarenciaOperadorFactory;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Doctrine\ORM\EntityManager;

class Sm00034001DescontoPeriodoCarenciaOperadorService
{
    protected $connection;
    protected $descontoPeriodoOperadorFactory;
    protected $environment;
    protected $newCode;

    public function __construct(Sm00034001DescontoPeriodoCarenciaOperadorFactory $descontoPeriodoOperadorFactory, Environment $environment, NewCode $newCode, EntityManager $entityManager)
    {
        $this->descontoPeriodoOperadorFactory = $descontoPeriodoOperadorFactory;
        $this->environment                    = $environment;
        $this->newCode                        = $newCode;
        $this->connection                     = $entityManager->getConnection();
    }

    public function getDescontoPeriodoCarenciaOperador()
    {
        return $this->descontoPeriodoOperadorFactory->getDescontoPeriodoCarenciaOperador();
    }

    public function getIdBloq()
    {
        return $this->descontoPeriodoOperadorFactory->getIdBloq();
    }

    public function botaoAtivar($parametros)
    {
        $this->connection->beginTransaction();
        try {
                $dataParam = array(
                    "IDBLOQCARENCMAXI"       =>  $parametros['IDBLOQCARENCMAXI'],
                ); 
                $this->descontoPeriodoOperadorFactory->botaoAtivar($dataParam);
                $this->connection->commit();
            } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }

    public function inserirDescontoPeriodoCarenciaOperador($parametros)
    {
        $cdoperador = $this->environment->getCdOperador();
        $NRORG = $this->environment->getNrOrg();
        $this->connection->beginTransaction();
        $paramsaux = array(
            "NRPARCNEGOCIO" => $parametros[0]['NRPARCNEGOCIO'],
            "NRCARENCIAOPER" => $parametros[0]['NRCARENCIAOPER']
        );
        $dados = $this->descontoPeriodoOperadorFactory->validaDescontoPeriodoCarenciaOperador($paramsaux);
        try {
            foreach ($parametros as $chave => $linha) {
                if ($linha["NRCARENCIAOPER"] == 0) {
                    $NRCARENCIAOPER = $this->newCode->getCodeByTableName("FCT_CARENCIAOPER", $NRORG, 1, 10, true);
                    if ($dados[0]["VALIDAOPER"] > 0) {
                        throw new \Exception("EXISTE");
                    } 
                    else {  
                        $dataParam = array(
                            "NRCARENCIAOPER" => $NRCARENCIAOPER,
                            "NRPARCNEGOCIO"   => $linha["NRPARCNEGOCIO"],
                            "NRDAISMAXCARENCIA" => 9999,
                            "IDATIVO"       => "S",
                            "NRORG"              => $NRORG,
                            "NRORGINCLUSAO"      => $NRORG,
                            "CDOPERINCLUSAO"     => $cdoperador,
                            "NRPARCELASMAX"      => $linha["NRPARCELASMAX"],
                            "VRPERCMAXATE"       => $linha["VRPERCMAXATE"],
                        );
                        $this->descontoPeriodoOperadorFactory->inserirDescontoPeriodoCarenciaOperador($dataParam);      
                    }   
                } else {
                    if ($dados[0]["VALIDAOPER"] > 0) {
                        throw new \Exception("EXISTE");
                    }  
                    else {
                        $dataParam = array(
                            "NRPARCNEGOCIO"   => $linha["NRPARCNEGOCIO"],
                            "NRDAISMAXCARENCIA" => 9999,
                            "IDATIVO"       => "S",
                            "NRORG"              => $NRORG,
                            "CDOPERULTATU" => $cdoperador,
                            "NRORGULTATU" => $NRORG,
                            "NRPARCELASMAX"      => $linha["NRPARCELASMAX"],
                            "VRPERCMAXATE"       => $linha["VRPERCMAXATE"],
                            "NRCARENCIAOPER" => $linha["NRCARENCIAOPER"],
                        );
                        $this->descontoPeriodoOperadorFactory->atualizarDescontoPeriodoCarenciaOperador($dataParam); 
                    }
                }
            }
            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }

    public function deletarDescontoPeriodoCarenciaOperador($parametros)
    {
        $this->connection->beginTransaction();
        try {
            foreach ($parametros as $chave => $linha) {
                $dataParam = array("NRCARENCIAOPER" => $linha["NRCARENCIAOPER"],);
                $this->descontoPeriodoOperadorFactory->deletarDescontoPeriodoCarenciaOperador($dataParam);
            }
            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }
}
