<?php

namespace SM\Service;

use SM\Factory\Sm00034002DescontoPeriodoCarenciaPerfilAcessoFactory;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Doctrine\ORM\EntityManager;

class Sm00034002DescontoPeriodoCarenciaPerfilAcessoService
{
    protected $connection;
    protected $descontoPeriodoPerfilAcessoFactory;
    protected $environment;
    protected $newCode;

    public function __construct(Sm00034002DescontoPeriodoCarenciaPerfilAcessoFactory $descontoPeriodoPerfilAcessoFactory, Environment $environment, NewCode $newCode, EntityManager $entityManager)
    {
        $this->descontoPeriodoPerfilAcessoFactory = $descontoPeriodoPerfilAcessoFactory;
        $this->environment                        = $environment;
        $this->newCode                            = $newCode;
        $this->connection                         = $entityManager->getConnection();
    }

    public function getDescontoPeriodoCarenciaPerfilAcesso()
    {
        return $this->descontoPeriodoPerfilAcessoFactory->getDescontoPeriodoCarenciaPerfilAcesso();
    }

    public function inserirDescontoPeriodoCarenciaPerfilAcesso($parametros)
    {
        $cdoperador = $this->environment->getCdOperador();
        $NRORG = $this->environment->getNrOrg();
        $this->connection->beginTransaction();
        $paramsaux = array(
            "NRPERFILACESSO" => $parametros[0]['NRPERFILACESSO'],
            "NRCARENCIAPERFIL" => $parametros[0]['NRCARENCIAPERFIL']
        );

        $dados = $this->descontoPeriodoPerfilAcessoFactory->validaDescontoPeriodoCarenciaPerfilAcesso($paramsaux);
        try {
            foreach ($parametros as $linha) {
                if ($linha["NRCARENCIAPERFIL"] == 0) {
                    $NRCARENCIAPERFIL = $this->newCode->getCodeByTableName("FCT_CARENCIAPERFIL", $NRORG, 1, 10, true);
                    $dataParam = array(
                        "NRCARENCIAPERFIL" => $NRCARENCIAPERFIL,
                        "NRPERFILACESSO"   => $linha["NRPERFILACESSO"],
                        "NRDAISMAXCARENCIA" => 90,
                        "IDATIVO"       => "S",
                        "NRORG"              => $NRORG,
                        "NRORGINCLUSAO"      => $NRORG,
                        "CDOPERINCLUSAO"     => $cdoperador,
                        "NRPARCELASMAX"      => $linha["NRPARCELASMAX"],
                        "VRPERCMAXDE"          => 99,
                        "VRPERCMAXATE"       => $linha["VRPERCMAXATE"],
                    );
                    if ($dados[0]["VALIDAPERF"] > 0) {
                        throw new \Exception("EXISTE");
                    } else {
                        $this->descontoPeriodoPerfilAcessoFactory->inserirDescontoPeriodoCarenciaPerfilAcesso($dataParam);
                    }
                } else {
                    $dataParam = array(
                        "NRPERFILACESSO"   => $linha["NRPERFILACESSO"],
                        "NRDAISMAXCARENCIA" => 90,
                        "IDATIVO"       => "S",
                        "NRORG"              => $NRORG,
                        "CDOPERULTATU" => $cdoperador,
                        "NRORGULTATU" => $NRORG,
                        "NRPARCELASMAX"      => $linha["NRPARCELASMAX"],
                        "VRPERCMAXDE"          => 99,
                        "VRPERCMAXATE"       => $linha["VRPERCMAXATE"],
                        "NRCARENCIAPERFIL" => $linha["NRCARENCIAPERFIL"],
                    );
                    if ($dados[0]["VALIDAPERF"] > 0) {
                        throw new \Exception("EXISTE");
                    } else {
                        $this->descontoPeriodoPerfilAcessoFactory->atualizarDescontoPeriodoCarenciaPerfilAcesso($dataParam);
                    }
                }
            }
            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }

    public function deletarDescontoPeriodoCarenciaPerfilAcesso($parametros)
    {
        $this->connection->beginTransaction();
        try {
            foreach ($parametros as $linha) {
                $dataParam = array("NRCARENCIAPERFIL" => $linha["NRCARENCIAPERFIL"]);
                $this->descontoPeriodoPerfilAcessoFactory->deletarDescontoPeriodoCarenciaPerfilAcesso($dataParam);
            }
            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }
}
